pub struct LaneWideProduct<O, const N: usize>(pub [O; N]);Expand description
One independent deferred wide product per SubU lane of a Divide widening multiply. Lanes
accumulate (Add/Sub/Sum) and reduce independently, mirroring the packing structure, so a
sum of products is reduced only once per lane. N is the lane count.
Tuple Fields
0: [O; N]Trait Implementations
Sourceimpl<O: Copy + Add<Output = O>, const N: usize> AddAssign for LaneWideProduct<O, N>
impl<O: Copy + Add<Output = O>, const N: usize> AddAssign for LaneWideProduct<O, N>
Sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
Performs the
+= operation. Read moreSourceimpl<O: Clone, const N: usize> Clone for LaneWideProduct<O, N>
impl<O: Clone, const N: usize> Clone for LaneWideProduct<O, N>
Sourcefn clone(&self) -> LaneWideProduct<O, N>
fn clone(&self) -> LaneWideProduct<O, N>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<O: Copy + Sub<Output = O>, const N: usize> SubAssign for LaneWideProduct<O, N>
impl<O: Copy + Sub<Output = O>, const N: usize> SubAssign for LaneWideProduct<O, N>
Sourcefn sub_assign(&mut self, rhs: Self)
fn sub_assign(&mut self, rhs: Self)
Performs the
-= operation. Read moreimpl<O: Copy, const N: usize> Copy for LaneWideProduct<O, N>